@@ -1,10 +1,7 @@
 from django.contrib import auth
 from django.utils.translation import gettext as _
 from rest_framework import serializers
-from rest_framework.authentication import (
-    SessionAuthentication,
-    TokenAuthentication
-)
+from rest_framework.authentication import SessionAuthentication, TokenAuthentication
 from rest_framework.decorators import api_view, permission_classes
 from rest_framework.permissions import IsAuthenticated
 from rest_framework.settings import api_settings
@@ -13,7 +10,7 @@ from rest_registration.decorators import (
     api_view_serializer_class,
     api_view_serializer_class_getter
 )
-from rest_registration.exceptions import BadRequest
+from rest_registration.exceptions import LoginInvalid, UserNotFound
 from rest_registration.settings import registration_settings
 from rest_registration.utils.responses import get_ok_response
 
@@ -27,22 +24,20 @@ def login(request):
     Logs in the user via given login and password.
     '''
     serializer_class = registration_settings.LOGIN_SERIALIZER_CLASS
-    serializer = serializer_class(
-        data=request.data,
-        context={'request': request},
-    )
+    serializer = serializer_class(data=request.data, context={'request': request})
     serializer.is_valid(raise_exception=True)
-    user = serializer.get_authenticated_user()
-
-    if not user:
-        raise BadRequest(_("Login or password invalid."))
+    login_authenticator = registration_settings.LOGIN_AUTHENTICATOR
+    try:
+        user = login_authenticator(serializer.validated_data, serializer=serializer)
+    except UserNotFound:
+        raise LoginInvalid() from None
 
     extra_data = perform_login(request, user)
 
     return get_ok_response(_("Login successful"), extra_data=extra_data)
 
 
-class LogoutSerializer(serializers.Serializer):  # noqa: E501 pylint: disable=abstract-method
+class LogoutSerializer(serializers.Serializer):  # pylint: disable=abstract-method
     revoke_token = serializers.BooleanField(default=False)
 
 
